# Copyright (C) 2012 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Internal Gwibber exceptions."""

__all__ = [
    'AuthorizationError',
    'GwibberError',
    'UnsupportedProtocolError',
    ]


class GwibberError(Exception):
    """Base class for all internal Gwibber exceptions."""


class AuthorizationError(GwibberError):
    """Backend service authorization errors."""

    def __init__(self, account, message):
        self.account = account
        self.message = message

    def __str__(self):
        return '{} (account: {})'.format(self.message, self.account)


class UnsupportedProtocolError(GwibberError):
    def __init__(self, protocol):
        self.protocol = protocol

    def __str__(self):
        return 'Unsupported protocol: {}'.format(self.protocol)
